use strict;
package Spark::Form::Printer;
BEGIN {
  $Spark::Form::Printer::VERSION = '0.2103'; # TRIAL
}

# ABSTRACT: interface for form printers for C<Spark::Form>
use Moose::Role;

1;


=pod

=head1 NAME

Spark::Form::Printer - interface for form printers for C<Spark::Form>

=head1 VERSION

version 0.2103

=head1 SEE ALSO

=over 4

=item L<Spark::Form> - the forms module that started it all

=item L<Spark::Form::BasicPrinters> - set of pre-canned printers for your forms

=back

=head1 AUTHOR

James Laver L<http://jameslaver.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

