use strict;
package SparkX::Form::BasicFields;
BEGIN {
  $SparkX::Form::BasicFields::VERSION = '0.2103'; # TRIAL
}

# ABSTRACT: A collection of basic fields for Spark::Form

1;


=pod

=head1 NAME

SparkX::Form::BasicFields - A collection of basic fields for Spark::Form

=head1 VERSION

version 0.2103

=head1 DESCRIPTION

L<Spark::Form> is a way to define your own forms with validation and auto-printing. See that module for more information.

This file is just explanatory. SEE ALSO for more interesting files.

=head1 SEE ALSO

=over 4

=item L<Spark::Form> - The forms handling system itself

=item L<SparkX::BasicValidators> - If you want to have validation of these fields

=item L<SparkX::Form::Field::Text> - A text field

=item L<SparkX::Form::Field::Checkbox> - A checkbox field

=item L<SparkX::Form::Field::Radio> - A radio button set

=item L<SparkX::Form::Field::Select> - A select button set

=item L<SparkX::Form::Field::TextArea> - A textarea field

=back

=head1 ACKNOWLEDGEMENTS

=head1 AUTHOR

James Laver L<http://jameslaver.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

