use strict;
package SparkX::Form::BasicPrinters;
BEGIN {
  $SparkX::Form::BasicPrinters::VERSION = '0.2103'; # TRIAL
}

# ABSTRACT: A selection of basic form printers for printing a C<SparkX::Form>.

1;


=pod

=head1 NAME

SparkX::Form::BasicPrinters - A selection of basic form printers for printing a C<SparkX::Form>.

=head1 VERSION

version 0.2103

=head1 SEE ALSO

=over 4

=item L<SparkX::Form> - The forms module that started it all

=item L<SparkX::Form::Printer> - The interface that printers must fulfil

=item L<SparkX::Form::Printer::List> - A printer that prints a HTML list

=back

=head1 AUTHOR

James Laver L<http://jameslaver.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

